@@ -1,4 +1,4 @@
-from connection_controller import ConnectionController
+from eon_rabbit_client.connection_controller import ConnectionController
 from aio_pika import RobustChannel
 
 class ChannelController():
