@@ -1,4 +1,4 @@
-from channel_controller import ChannelController
+from eon_rabbit_client.channel_controller import ChannelController
 
 class ExchangeController():
     def __init__(self, channel_controller: ChannelController):
